<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Order;
use App\Repositories\Admin\KfalaRepository;
use App\Repositories\Admin\OrdersRepository;
use App\Repositories\Client\UsersRepository;
use Illuminate\Http\Request;

class KfalaController extends Controller
{
    /**
     * @var KfalaRepository
     */
    private $kfalaRepository;
    /**
     * @var OrdersRepository
     */
    private $ordersRepository;
    /**
     * @var UsersRepository
     */
    private $usersRepository;

    public function __construct(KfalaRepository $kfalaRepository, OrdersRepository $ordersRepository, UsersRepository $usersRepository)
    {
        $this->kfalaRepository = $kfalaRepository;
        $this->ordersRepository = $ordersRepository;
        $this->usersRepository = $usersRepository;
        $this->middleware(['permission:kfala,admin']);
    }

    public function index()
    {
        $rows = $this->kfalaRepository->index();
        $orders = $this->ordersRepository->index();

        return view('admin.kfala.index', compact('rows', 'orders'));
    }

    public function getNewClientInfo(Request $request)
    {
        return $this->ordersRepository->getInfo($request['client_mobile']);
    }

    public function store(Request $request)
    {
        $client = $this->usersRepository->checkUserExist();

        if ($client && $client->mobile != $request['client_mobile']) {
            $validation = 'required|unique:users,email|email';
        } elseif ($client) {
            $validation = 'required|email';
        } else {
            $validation = 'required|email';

        }

        $this->validate($request, [
            'client_name' => 'required',
            'client_mobile' => 'required',
            'client_email' => $validation,
            'family_card' => 'required',
            'order_id' => 'required|exists:orders,id'
        ]);

        $client = $this->usersRepository->createNewAccount();

        $order = $this->ordersRepository->order($request['order_id']);


        return $this->kfalaRepository->transfer_kfala($client, $order);


    }
}
