<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Alert;
use App\Models\Order;
use App\Models\Transfer;
use App\Models\User;
use Illuminate\Http\Request;

class TransfersController extends Controller
{

    public function __construct()
    {
        $this->middleware(['permission:transfers,admin']);
    }

    public function index()
    {
        $rows = Transfer::orderByDesc('id')->paginate(20);
        $offices = User::whereType('foreign')->get();
        return view('admin.transfers.index', compact('rows', 'offices'));
    }

    public function destroy($id)
    {
        Transfer::destroy($id);
        success_toast();
        return redirect()->back();
    }

    public function transfers($order_id)
    {
        $row = Order::find($order_id);
        return view('admin.orders.transfers', compact('row'));
    }

    public function transfer_post(Request $request)
    {
        $this->validate($request, [
            'price' => 'required|numeric',
            'image' => 'required|image'
        ]);
$order = Order::find($request->order_id);
        $transfer = new Transfer();
        $transfer->price = $request->price;
        $transfer->order_id = $request->order_id;
        $transfer->office_id = $request->office_id;
        $transfer->code = rand(1111, 9999);
        if ($request->has('image')) $transfer->setImageAttribute();
        $transfer->save();

        Order::where('id', $request->order_id)->update(['transfer_money_status' => 'true', 'foreign_money_wallet' => $request->foreign_money_wallet]);

        $alert = new Alert();
        $alert->order_id = $request->order_id;
        $alert->user_id = $request->office_id;
        $alert->type = 'transfer money';
        $alert->status = 'new';
        $alert->notes = "Amount has been transferred {$request->price} with order code {$order->code} ";
        $alert->save();

        toast('تم اضافه التحويل بنجاح', 'success');
        return redirect()->route('all_orders.index');
    }

    public function transfer_filter(Request $request)
    {
        $rows = Transfer::orderByDesc('id');
        if ($request['office_id']) {
            $rows->office_id = $request['office_id'];
        }
        if ($request['date_from'] && $request['date_to'] == null) {
            $rows->where('created_at', '>=', $request['date_from']);
        }
        if ($request['date_from'] == null && $request['date_to']) {
            $rows->where('created_at', '<=', $request['date_to']);
        }
        if ($request['date_from'] && $request['date_to']) {
            $rows->whereBetween('created_at', [$request['date_from'], $request['date_to']]);
        }
        $rows = $rows->paginate(20);
        $offices = User::whereType('foreign')->get();
        return view('admin.transfers.index', compact('rows', 'offices'));
    }

}
