<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Order;
use Carbon\Carbon;
use Illuminate\Http\Request;

class TravelsController extends Controller
{

    public function __construct()
    {
        $this->middleware(['permission:travels,admin']);
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rows = Order::whereHas('travel')->orderByDesc('id')->paginate(10);
        $next_rows = Order::where('status', '!=', 'cancel')->whereHas('travel', function ($q) {
            $q->whereDate('date_arrive_flight', '>', Carbon::now()->toDateString());
        })->orderByDesc('id')->paginate(10);
        $done_rows = Order::whereHas('travel')->where('status', 'delivered')->orderByDesc('id')->paginate(10);
        $cancel_rows = Order::whereHas('travel')->where('status', 'cancel')->orderByDesc('id')->paginate(10);

        return view('admin.orders.travel', compact('rows', 'next_rows', 'done_rows', 'cancel_rows'));
    }

    public function delete_travel_ajax()
    {
        $ids = explode(",", request()->ids);
        foreach ($ids as $id) {
            $order = Order::find($id);
            $order->delete();
        }
        return response()->json(['data' => 'done']);
    }

    public function printReceiveLetter($order_id, Request $request)
    {
        $this->validate($request, [
            'mandob_name' => 'required',
            'mandob_number' => 'required',
        ]);
        $order = Order::findOrFail($order_id);
        $order->mandob_name = $request['mandob_name'];
        $order->mandob_number = $request['mandob_number'];
        $order->update();
        return redirect()->route('receive_letter', $order->id);
    }

    public function receive_letter($order_id)
    {
        $order = Order::findOrFail($order_id);
        return view('admin.orders.receive_letter', compact('order'));
    }

    public function printDeliverLetter($order_id, Request $request)
    {
        $this->validate($request, [
            'mandob_name' => 'required',
            'mandob_number' => 'required',
        ]);
        $order = Order::findOrFail($order_id);
        $order->mandob_name = $request['mandob_name'];
        $order->mandob_number = $request['mandob_number'];
        $order->update();
        return redirect()->route('deliver_letter', $order->id);
    }

    public function deliver_letter($order_id)
    {
        $order = Order::findOrFail($order_id);
        return view('admin.orders.deliver_letter', compact('order'));
    }

}
