<?php

namespace App\Http\Controllers\Clients;

use App\Http\Controllers\Controller;
use App\Models\Order;
use App\Models\OrderUpdateRequests;
use App\Repositories\Client\OrderProcessesRepository;
use App\Repositories\Client\OrdersRepository;
use App\Repositories\Client\OrderTravelRepository;
use App\Repositories\Foreign\ResumesRepository;
use Illuminate\Http\Request;

class OrdersController extends Controller
{
    private $ordersRepository;
    private $orderProcessesRepository;
    private $orderTravelRepository;
    private $resumesRepository;

    public function __construct(OrdersRepository $ordersRepository, OrderProcessesRepository $orderProcessesRepository, OrderTravelRepository $orderTravelRepository, ResumesRepository $resumesRepository)
    {
        $this->ordersRepository = $ordersRepository;
        $this->orderProcessesRepository = $orderProcessesRepository;
        $this->orderTravelRepository = $orderTravelRepository;
        $this->resumesRepository = $resumesRepository;
    }

    public function client_orders()
    {
        $rows = $this->ordersRepository->client_orders();
        return view('site.client.orders', compact('rows'));
    }

    public function client_single_order($id)
    {
        $row = $this->ordersRepository->client_single_order($id);
        $processes = $this->orderProcessesRepository->order_processes($id);
        $travel = $this->orderTravelRepository->order_travel($id);
        $updates = OrderUpdateRequests::where('order_id', $id)->get();
        return view('site.client.single_order', compact('row', 'processes', 'travel', 'updates'));
    }

    public function sendUpdateOrder($id)
    {
        $order = Order::find($id);
        $last_update_order = OrderUpdateRequests::where('order_id', $id)->whereIn('status', ['client_send', 'foreign_replay'])->count();
        if ($last_update_order > 0) {
            toast('يوجد طلب تحديث لم يرد عليه بعد', 'error');
            return redirect()->back();
        }
        $update_order = new OrderUpdateRequests();
        $update_order->order_id = $id;
        $update_order->office_id = $order->office_id;
        $update_order->client_id = $order->client_id;
        $update_order->status = 'client_send';
        $update_order->save();

        toast('تم ارسال الطلب بنجاح', 'success');
        return redirect()->back();
    }

    public function resumes_show($id){
        $row = $this->resumesRepository->show($id);
        return view('site.client.resumes_show', compact('row'));
    }
}
