<?php


namespace App\Repositories\Foreign;


use App\Models\Order;
use App\Models\OrderProcess;
use App\Models\OrderTravel;
use App\Models\User;
use Carbon\Carbon;

class OrdersRepository
{

    public function index()
    {
        return Order::whereOfficeId(\Auth::id())->latest()->get();
    }

    public function order($id)
    {
        return Order::find($id);
    }

    public function orders($status = null)
    {
        $office_id = \Auth::user()->id;
        if ($status) {
            $rows = Order::where(['office_id' => $office_id, 'status' => $status])->latest()->paginate(10);
        } else {
            $rows = Order::where('office_id', $office_id)->where('status', '!=', 'new')->latest()->paginate(10);
        }
        return $rows;
    }

    public function home_orders()
    {
        return Order::whereOfficeId(\Auth::id())->orderByDesc('id')->get()->take(5);
    }

    public function orders_foreign_ajax()
    {
        $ids = request()->ids;
        $sms_rows = Order::whereIn('id', explode(",", $ids))->get();
        $view = view('site.foreign.model_ajax', compact('sms_rows'))->render();
        return response()->json(['html' => $view]);
    }

    public function order_search()
    {
        $office_id = \Auth::user()->id;
        $code = request()->order_code;
        $rows = Order::where('office_id', $office_id)->where('code', 'LIKE', "%$code%")->latest()->paginate(10);
        $view = view('site.foreign.order_ajax', compact('rows'))->render();
        return response()->json(['html' => $view]);
    }

    public function change_orders_status($status)
    {
        $ids = explode(",", request()->ids);
        foreach ($ids as $id) {
            $order = Order::find($id);
            $order->status = $status;
            $order->update();
        }
        return response()->json(['data' => 'done']);
    }

    public function add_processes()
    {
        $process = new OrderProcess();
        $process->order_id = request()->order_id;
        $process->status = 'current';
        $process->start_date = request()->start_date;
        $process->end_date = request()->end_date;
        $process->setImageAttribute();
        $process->process = request()->process;
        $process->save();
    }

    public function change_travel($id = null)
    {
        if ($id) {
            $travel = OrderTravel::find($id);
            $travel->order_id = request()->order_id;
            $travel->number_flight = request()->number_flight;
            $travel->date_flight = request()->date_flight;
            $travel->date_arrive_flight = request()->date_arrive_flight;
            $travel->warranty = Carbon::parse(request()->date_arrive_flight)->addMonths(3)->toDateString();
            $travel->destination = request()->destination;
            $travel->came_from = request()->came_from;
            $travel->flight_company = request()->flight_company;
            $travel->flight_time = request()->flight_time;
            $travel->update();
        }
        $travel = new OrderTravel();
        $travel->order_id = request()->order_id;
        $travel->number_flight = request()->number_flight;
        $travel->date_flight = request()->date_flight;
        $travel->date_arrive_flight = request()->date_arrive_flight;
        $travel->warranty = Carbon::parse(request()->date_arrive_flight)->addMonths(3)->toDateString();
        $travel->destination = request()->destination;
        $travel->came_from = request()->came_from;
        $travel->flight_company = request()->flight_company;
        $travel->flight_time = request()->flight_time;
        $travel->save();

    }

    public function order_travel($order_id)
    {
        return OrderTravel::where('order_id', $order_id)->first();
    }

    public function index_order_travels()
    {
        $rows = OrderTravel::latest()->paginate(10);
        $next_travels = OrderTravel::whereHas('order', function ($query) {
            $query->where('status', '!=', 'cancel');
        })->whereDate('date_arrive_flight', '>', Carbon::now())->latest()->paginate(10);
        $completes = OrderTravel::whereHas('order', function ($query) {
            $query->where('status', 'delivered');
        })->latest()->paginate(10);
        $cancels = OrderTravel::whereHas('order', function ($query) {
            $query->where('status', 'cancel');
        })->latest()->paginate(10);
        return view('site.foreign.flights', compact('rows', 'next_travels', 'completes', 'cancels'));
    }

    public function refuse_order($id)
    {
        $order = Order::find($id);
        $order->status = 'cancel';
        $order->reason = request()->cancel_select . ' ' . request()->reason;
        $order->update();
    }

    public function cancel_order($id)
    {
        $order = Order::find($id);
        $order->status = 'cancel';
        $order->admin_approve_cancel = 'true';
        $order->reason = request()->cancel_select . ' ' . request()->reason;
        $order->update();
    }

    public function trusted_office_cancel($id)
    {
        $order = Order::findOrFail($id);
        $order->admin_approve_cancel = 'wait';
        $order->update();

    }

    public function accept_order($id)
    {
        $order = Order::find($id);
        $order->status = 'foreign_accept';
        $order->update();
    }


    public function search_travels()
    {
        return OrderTravel::whereHas('order', function ($query) {
            $query->where('code', 'LIKE', "%" . request()->order_code . "%");
        })->latest()->paginate(10);

    }

}
