<?php


namespace App\Repositories\Worker;


use App\Models\Order;
use App\Models\User;
use Carbon\Carbon;

class OrdersRepository
{

    public function index()
    {
        return Order::latest()->get();
    }

    public function home_orders()
    {
        return Order::latest()->get()->take(5);
    }

    public function order($id)
    {
        return Order::find($id);
    }

    public function orders($status = null)
    {
        if ($status) {
            $rows = Order::where('status', $status)->latest()->paginate(10);
        } else {
            $rows = Order::latest()->paginate(10);
        }
        return $rows;
    }

    public function orders_clients_ajax()
    {
        $ids = request()->ids;
        $sms_rows = Order::whereIn('id', explode(",", $ids))->get();
        if (request()->polo == true) {
            $view = view('admin.orders.model_polo_ajax', compact('sms_rows'))->render();

        } else {
            $view = view('admin.orders.model_sms_ajax', compact('sms_rows'))->render();

        }
        return response()->json(['html' => $view]);
    }

    public function order_search()
    {
        $code = request()->order_code;
        $rows = Order::where('code', 'LIKE', "%$code%")->latest()->paginate(10);
        $view = view('site.saudi.order_ajax', compact('rows'))->render();
        return response()->json(['html' => $view]);
    }

    public function change_orders_status($status)
    {
        $ids = explode(",", request()->ids);
        foreach ($ids as $id) {
            $order = Order::find($id);
            $order->status = $status;
            if ($status == 'cancel') {
                $order->cancel_type = 'worker_refuse';
            }
            if ($status == 'delivered') {
                $order->warranty = Carbon::now();
            }
            $order->update();
        }

        return response()->json(['data' => 'done']);
    }

    public function store()
    {
        $client = session()->get('client');
        $order_details = session()->get('order_details');
        $order = new Order();
        $order->client_name = $client->name;
        $order->client_mobile = $client->mobile;
        $order->civil_registry = $client->civil_registry;
        $order->city = $client->city;
        $order->type = 'as_requested';
        $order->area = $client->area;
        $order->family_count = $client->family_count;
        $order->social_status = $client->social_status;
        $order->another_mobile = $client->another_mobile;
        $order->client_email = $client->email;
        $order->client_residency_number = $client->client_residency_number;
        $order->visa_number = $order_details['visa_number'];
        $order->nationality_id = $order_details['nationality_id'];
        $order->gender = $order_details['gender'];
        $order->job_title_id = $order_details['job_title_id'];
        $order->cv_id = $order_details['cv_id'];
//        $order->passport_image = $order_details['passport_image'];
        $order->family_card = $order_details['family_card'];
        $client->family_card = $order_details['family_card'];
        $order->follow_type = request()->follow_type;
        $order->setAnyAttribute('client_sign');
        $cv = new CvsRepository();
        $cv = $cv->show($order_details['cv_id']);
        $order->office_id = $cv->office_id;
        $order->status = 'new';
        $order->client_id = $client->id;
        $order->another_mobile = $client->another_mobile;
        $order->completed = 'true';

        $order->save();
        $order->code = rand(111, 999) . $order->id;
        $order->update();
        // SEND EMAIL

        $client_notification = new SendMessagesRepository();


        if ($client->first_login == 'true') {
            $new_password = rand('1111', '9999');
            User::whereId($client->id)->update([
                'password' => bcrypt($new_password)
            ]);
            $client_notification->sendPasswordSmsEmail($client->email, $new_password, $client->mobile, request()->follow_type);
        }

        session()->forget(['client', 'order_details', 'client_mobile']);
        return redirect()->route('last_requested_order', $order->id);

    }

}
