<?php

namespace App\Http\Controllers;


use App\Http\Controllers\Foreign\AlertsController;
use App\Http\Controllers\Foreign\ComplaintsController;
use App\Http\Controllers\Foreign\HomeController;

use App\Http\Controllers\Foreign\ResumesController;
use App\Http\Controllers\Foreign\UsersController;
use App\Http\Controllers\Foreign\OrdersController;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\Request;


$locale = Request::segment(1);

if ($locale == Config::get('app.available_locales')) {
    \App::setLocale($locale);
} else {
    $locale = null;
}


Route::get('/language/{lang}', [HomeController::class, 'change_language_web'])->name('language')->middleware('lang');
Route::get('worker_name_ajax_foreign', [ComplaintsController::class, 'worker_name_ajax_foreign'])->name('worker_name_ajax_foreign');


Route::group(['prefix' => $locale . '/foreign', 'middleware' => 'lang'], function () {

    Route::get('/', [HomeController::class, 'index'])->name('foreign_home');

    Route::get('login_form', [UsersController::class, 'login_form'])->name('login_form_foreign');
    Route::post('login', [UsersController::class, 'login'])->name('login_foreign');
    Route::get('forget_password_form', [UsersController::class, 'forget_password_form'])->name('forget_password_form_foreign');
    Route::post('forget_password', [UsersController::class, 'forget_password_check_mobile'])->name('forget_password_foreign');
    Route::post('mobile_confirm', [UsersController::class, 'mobile_confirm'])->name('mobile_confirm_foreign');
    Route::post('change_password', [UsersController::class, 'change_password'])->name('change_password_foreign');
    Route::get('forget_password', [UsersController::class, 'forget_password'])->name('forget_password_foreign');


    Route::group(['middleware' => 'foreign'], function () {

        Route::get('logout', [UsersController::class, 'logout'])->name('logout_foreign');

        Route::get('orders', [OrdersController::class, 'orders'])->name('order_foreign');
        Route::get('order_ajax_foreign', [OrdersController::class, 'order_ajax'])->name('order_ajax_foreign');
        Route::get('orders_foreign_ajax', [OrdersController::class, 'orders_foreign_ajax'])->name('orders_foreign_ajax');
        Route::post('send_complaint_foreign', [OrdersController::class, 'send_complaint_foreign'])->name('send_complaint_foreign');
        Route::post('orders_change_in_progress', [OrdersController::class, 'orders_change_in_progress'])->name('orders_change_in_progress');
        Route::post('orders_change_travel', [OrdersController::class, 'orders_change_travel'])->name('orders_change_travel');
        Route::get('order_search_ajax', [OrdersController::class, 'order_search_ajax'])->name('order_search_foreign_ajax');
        Route::get('single_order/{id}', [OrdersController::class, 'single_order'])->name('single_order_foreign');
        Route::get('add_processes/{order_id}', [OrdersController::class, 'add_processes'])->name('add_processes');
        Route::post('add_processes_form', [OrdersController::class, 'add_processes_form'])->name('add_processes_form');
        Route::get('change_travel/{order_id}', [OrdersController::class, 'change_travel'])->name('change_travel');
        Route::post('change_travel_form/{id?}', [OrdersController::class, 'change_travel_form'])->name('change_travel_form');
        Route::post('refuse_order/{id}', [OrdersController::class, 'refuse_order'])->name('refuse_order');
        Route::post('cancel_order/{id}', [OrdersController::class, 'cancel_order'])->name('cancel_order');
        Route::post('accept_order/{id}', [OrdersController::class, 'accept_order'])->name('accept_order');
        Route::get('order_travels', [OrdersController::class, 'index_order_travels'])->name('order_travels');
        Route::post('search_travels', [OrdersController::class, 'search_travels'])->name('search_travels');
        Route::get('cancelLetter/{order_id}', [OrdersController::class, 'cancelLetter'])->name('cancelLetter');


        Route::get('foreign_complaints', [ComplaintsController::class, 'index'])->name('foreign_complaints');
        Route::post('foreign_new_complaint', [ComplaintsController::class, 'store'])->name('foreign_new_complaint');
        Route::post('update_complaint/{complaint_id}', [ComplaintsController::class, 'update'])->name('foreign_update_complaint');
        Route::post('reply_complaint/{complaint_id}', [ComplaintsController::class, 'reply_complaint'])->name('foreign_reply_complaint');

        Route::get('foreign_alerts', [AlertsController::class, 'index'])->name('foreign_alerts');
        Route::get('close_alert/{alert_id}', [AlertsController::class, 'close_alert'])->name('close_alert');

        Route::get('get_reply_update_order', [OrdersController::class, 'get_reply_update_order'])->name('get_reply_update_order');

        Route::post('reply_update_order/{id}', [OrdersController::class, 'reply_update_order'])->name('reply_update_order');

        Route::get('foreign_transfers', [OrdersController::class, 'foreign_transfers'])->name('foreign_transfers');

        Route::get('done_transfer/{id}', [OrdersController::class, 'done_transfer'])->name('done_transfer');

        Route::resource('resumes', ResumesController::class);

    });


});
